netapp_ontap.models.shelf_acps API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.shelf_acps`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ShelfAcpsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ShelfAcps object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `address: str GET POST PATCH`

    The address field of the shelf_acps.

    Example: 192.168.1.104

  `channel: str GET POST PATCH`

    The channel field of the shelf_acps.

    Valid choices:

    - unknown
    - out_of_band
    - in_band
  `connection_state: str GET POST PATCH`

    The connection_state field of the shelf_acps.

    Valid choices:

    - no_connectivity
    - partial_connectivity
    - full_connectivity
    - additional_connectivity
    - unknown_connectivity
    - not_available
    - active
    - disabled
  `enabled: bool GET POST PATCH`

    The enabled field of the shelf_acps.

  `error: ShelfAcpsError GET POST PATCH`

    Error object is populated when connection_state becomes non-optimal

  `netmask: str GET POST PATCH`

    The netmask field of the shelf_acps.

    Example: 255.255.252.0

  `node: Node GET POST PATCH`

    The node field of the shelf_acps.

  `port: str GET POST PATCH`

    The port field of the shelf_acps.

    Example: e0P

  `subnet: str GET POST PATCH`

    The subnet field of the shelf_acps.

    Example: 192.168.0.1